'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = {
  performQuery: function performQuery(endpoint, query, variables) {
    var opts = {
      method: 'post',
      headers: {
        'Accept': 'application/json', //eslint-disable-line
        'Content-Type': 'application/json'
      },
      credentials: 'same-origin',
      body: JSON.stringify({ query: query, variables: variables })
    };

    return fetch(endpoint, opts).then(parseJSON);
  },
  performMutation: function performMutation(endpoint, mutation, variables, files) {
    if (!files) {
      return fetch(endpoint, {
        method: 'post',
        headers: {
          'Accept': 'application/json', // eslint-disable-line
          'Content-Type': 'application/json'
        },
        credentials: 'same-origin',
        body: JSON.stringify({
          query: mutation,
          variables: variables
        })
      }).then(parseJSON);
    }

    var formData = new FormData();
    formData.append('query', mutation);
    formData.append('variables', JSON.stringify(variables));
    if (files) {
      for (var filename in files) {
        if (files.hasOwnProperty(filename)) {
          formData.append(filename, files[filename]);
        }
      }
    }

    return fetch(endpoint, {
      method: 'post',
      credentials: 'same-origin',
      body: formData
    }).then(parseJSON);
  }
};


function parseJSON(res) {
  if (res.status !== 200) {
    throw new Error('Invalid request.');
  }

  return res.json().then(function (json) {
    return json.data;
  });
}
//# sourceMappingURL=defaultNetworkLayer.js.map